@@ -24,11 +24,11 @@ Device::Cisco::NXAPI - Interact with the NX-API (Nexus 9K Switches)
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -74,9 +74,9 @@ sub BUILD {
     my $uri = URI->new($self->uri);
     croak "Only http:// or https:// supported." if !($uri->scheme eq 'http' or $uri->scheme eq 'https');
 
-    $self->http_request(HTTP::Request->new(POST => $uri->scheme.$uri->host_port."/ins"));
+    $self->http_request(HTTP::Request->new(POST => $uri->scheme()."://".$uri->host_port()."/ins"));
     $self->http_request()->content_type("application/json-rpc");
-    $self->user_agent()->credentials($uri->host_port, 'Secure Zone', $self->username, $self->password);
+    $self->user_agent()->credentials($uri->host_port(), 'Secure Zone', $self->username, $self->password);
 }
 
 =head1 METHODS
@@ -408,7 +408,7 @@ The structure returned is as follows:
 sub physical_interfaces {
     my $self = shift;
 
-    my $ret = $self->_send_cmd('show interfaces');
+    my $ret = $self->_send_cmd('show interface');
     _fixup_returned_structure($ret);
     return _modify_returned_phy_int_structure($ret);
 }
